==> iam-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/iam/FromRoleArnOptions.java <==
package software.amazon.awscdk.services.iam;

/**
 * Options allowing customizing the behavior of {@link Role.fromRoleArn}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:09:31.993Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FromRoleArnOptions extends software.amazon.jsii.JsiiSerializable {
    /**
     * Whether the imported role can be modified by attaching policy resources to it.
     * 
     * Default: true
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Boolean getMutable();

    /**
     * @return a {@link Builder} of {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.Boolean mutable;

        /**
         * Sets the value of Mutable
         * @param mutable Whether the imported role can be modified by attaching policy resources to it.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mutable(java.lang.Boolean mutable) {
            this.mutable = mutable;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FromRoleArnOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public FromRoleArnOptions build() {
            return new Jsii$Proxy(mutable);
        }

    }

    /**
     * An implementation for {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FromRoleArnOptions {
        private final java.lang.Boolean mutable;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.mutable = this.jsiiGet("mutable", java.lang.Boolean.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Boolean mutable) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.mutable = mutable;
        }

        @Override
        public java.lang.Boolean getMutable() {
            return this.mutable;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getMutable() != null) {
                obj.set("mutable", om.valueToTree(this.getMutable()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FromRoleArnOptions.Jsii$Proxy that = (FromRoleArnOptions.Jsii$Proxy) o;

            return this.mutable != null ? this.mutable.equals(that.mutable) : that.mutable == null;
        }

        @Override
        public int hashCode() {
            int result = this.mutable != null ? this.mutable.hashCode() : 0;
            return result;
        }

    }
}

==> iam-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/iam/FromRoleArnOptions.java <==
package software.amazon.awscdk.services.iam;

/**
 * Options allowing customizing the behavior of {@link Role.fromRoleArn}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:49:14.099Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FromRoleArnOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether the imported role can be modified by attaching policy resources to it.
     * 
     * Default: true
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Boolean getMutable();

    /**
     * @return a {@link Builder} of {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.Boolean mutable;

        /**
         * Sets the value of Mutable
         * @param mutable Whether the imported role can be modified by attaching policy resources to it.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mutable(java.lang.Boolean mutable) {
            this.mutable = mutable;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FromRoleArnOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public FromRoleArnOptions build() {
            return new Jsii$Proxy(mutable);
        }
    }

    /**
     * An implementation for {@link FromRoleArnOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FromRoleArnOptions {
        private final java.lang.Boolean mutable;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.mutable = this.jsiiGet("mutable", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Boolean mutable) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.mutable = mutable;
        }

        @Override
        public java.lang.Boolean getMutable() {
            return this.mutable;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getMutable() != null) {
                obj.set("mutable", om.valueToTree(this.getMutable()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FromRoleArnOptions.Jsii$Proxy that = (FromRoleArnOptions.Jsii$Proxy) o;

            return this.mutable != null ? this.mutable.equals(that.mutable) : that.mutable == null;
        }

        @Override
        public int hashCode() {
            int result = this.mutable != null ? this.mutable.hashCode() : 0;
            return result;
        }
    }
}
